@@ -95,8 +95,8 @@ class ArgumentParserWithEnvAndConfig(ArgumentParser):
 class HelpFormatter(ArgumentDefaultsHelpFormatter):
     """A help formatter that provides the default value and the source it comes from."""
 
-    def __init__(self, prog: str) -> None:
-        super().__init__(prog, max_help_position=30, width=240)
+    def __init__(self, prog: str, **kwargs: Any) -> None:
+        super().__init__(prog, max_help_position=30, width=240, **kwargs)
 
     def _get_help_string(self, action: Action) -> str | None:
         text: str = super()._get_help_string(action) or ""
@@ -263,7 +263,7 @@ class ToxParser(ArgumentParserWithEnvAndConfig):
 
             def add_mutually_exclusive_group(**e_kwargs: Any) -> Any:
                 def add_argument(*a_args: str, of_type: type[Any] | None = None, **a_kwargs: Any) -> Action:
-                    res_args: Action = prev_add_arg(*a_args, **a_kwargs)  # type: ignore[has-type]
+                    res_args: Action = prev_add_arg(*a_args, **a_kwargs)
                     arguments.append((a_args, of_type, a_kwargs))
                     return res_args
 
