@@ -1,4 +1,5 @@
 """Load."""
+
 from __future__ import annotations
 
 from collections import defaultdict
@@ -31,11 +32,11 @@ class IniSource(Source):
         if content is None:
             if not path.exists():
                 raise ValueError
-            content = path.read_text()
+            content = path.read_text(encoding="utf-8")
         self._parser.read_string(content, str(path))
         self._section_mapping: defaultdict[str, list[str]] = defaultdict(list)
 
-    def transform_section(self, section: Section) -> Section:
+    def transform_section(self, section: Section) -> Section:  # noqa: PLR6301
         return IniSection(section.prefix, section.name)
 
     def sections(self) -> Iterator[IniSection]:
@@ -63,14 +64,14 @@ class IniSource(Source):
     def get_core_section(self) -> Section:
         return self.CORE_SECTION
 
-    def get_base_sections(self, base: list[str], in_section: Section) -> Iterator[Section]:
+    def get_base_sections(self, base: list[str], in_section: Section) -> Iterator[Section]:  # noqa: PLR6301
         for a_base in base:
             section = IniSection.from_key(a_base)
             yield section  # the base specifier is explicit
             if in_section.prefix is not None:  # no prefix specified, so this could imply our own prefix
                 yield IniSection(in_section.prefix, a_base)
 
-    def get_tox_env_section(self, item: str) -> tuple[Section, list[str], list[str]]:
+    def get_tox_env_section(self, item: str) -> tuple[Section, list[str], list[str]]:  # noqa: PLR6301
         return IniSection.test_env(item), [TEST_ENV_PREFIX], [PKG_ENV_PREFIX]
 
     def envs(self, core_config: ConfigSet) -> Iterator[str]:
@@ -106,9 +107,6 @@ class IniSource(Source):
                 if set(env.split("-")) - known_factors:
                     yield env
 
-    def __repr__(self) -> str:
-        return f"{type(self).__name__}(path={self.path})"
-
 
 __all__ = [
     "IniSource",
