@@ -1,27 +1,33 @@
-"""Contains the plugin manager object"""
+"""Contains the plugin manager object."""
+
 from __future__ import annotations
 
-from pathlib import Path
-from types import ModuleType
+import os
+from typing import TYPE_CHECKING, Any, Iterable
 
 import pluggy
 
 from tox import provision
-from tox.config.cli.parser import ToxParser
 from tox.config.loader import api as loader_api
-from tox.config.sets import ConfigSet, EnvConfigSet
 from tox.session.cmd.run import parallel, sequential
 from tox.tox_env import package as package_api
 from tox.tox_env.python.virtual_env import runner
 from tox.tox_env.python.virtual_env.package import cmd_builder, pyproject
 from tox.tox_env.register import REGISTER, ToxEnvRegister
 
-from ..execute import Outcome
-from ..session.state import State
-from ..tox_env.api import ToxEnv
 from . import NAME, spec
 from .inline import load_inline
 
+if TYPE_CHECKING:
+    from pathlib import Path
+    from types import ModuleType
+
+    from tox.config.cli.parser import ToxParser
+    from tox.config.sets import ConfigSet, EnvConfigSet
+    from tox.execute import Outcome
+    from tox.session.state import State
+    from tox.tox_env.api import ToxEnv
+
 
 class Plugin:
     def __init__(self) -> None:
@@ -29,12 +35,22 @@ class Plugin:
         self.manager.add_hookspecs(spec)
 
     def _register_plugins(self, inline: ModuleType | None) -> None:
-        from tox.session import state
-        from tox.session.cmd import depends, devenv, exec_, legacy, list_env, quickstart, show_config, version_flag
+        from tox.session import state  # noqa: PLC0415
+        from tox.session.cmd import (  # noqa: PLC0415
+            depends,
+            devenv,
+            exec_,
+            legacy,
+            list_env,
+            quickstart,
+            schema,
+            show_config,
+            version_flag,
+        )
 
         if inline is not None:
             self.manager.register(inline)
-        self.manager.load_setuptools_entrypoints(NAME)
+        self._load_external_plugins()
         internal_plugins = (
             loader_api,
             provision,
@@ -46,6 +62,7 @@ class Plugin:
             exec_,
             quickstart,
             show_config,
+            schema,
             devenv,
             list_env,
             depends,
@@ -58,6 +75,17 @@ class Plugin:
         self.manager.register(state)
         self.manager.check_pending()
 
+    def _load_external_plugins(self) -> None:
+        for name in os.environ.get("TOX_DISABLED_EXTERNAL_PLUGINS", "").split(","):
+            self.manager.set_blocked(name)
+        self.manager.load_setuptools_entrypoints(NAME)
+
+    def tox_extend_envs(self) -> list[Iterable[str]]:
+        additional_env_names_hook_value = self.manager.hook.tox_extend_envs()
+        # NOTE: S101 is suppressed below to allow for type narrowing in MyPy
+        assert isinstance(additional_env_names_hook_value, list)  # noqa: S101
+        return additional_env_names_hook_value
+
     def tox_add_option(self, parser: ToxParser) -> None:
         self.manager.hook.tox_add_option(parser=parser)
 
@@ -76,12 +104,18 @@ class Plugin:
     def tox_after_run_commands(self, tox_env: ToxEnv, exit_code: int, outcomes: list[Outcome]) -> None:
         self.manager.hook.tox_after_run_commands(tox_env=tox_env, exit_code=exit_code, outcomes=outcomes)
 
+    def tox_on_install(self, tox_env: ToxEnv, arguments: Any, section: str, of_type: str) -> None:
+        self.manager.hook.tox_on_install(tox_env=tox_env, arguments=arguments, section=section, of_type=of_type)
+
+    def tox_env_teardown(self, tox_env: ToxEnv) -> None:
+        self.manager.hook.tox_env_teardown(tox_env=tox_env)
+
     def load_plugins(self, path: Path) -> None:
         for _plugin in self.manager.get_plugins():  # make sure we start with a clean state, repeated in memory run
             self.manager.unregister(_plugin)
         inline = _load_inline(path)
         self._register_plugins(inline)
-        REGISTER._register_tox_env_types(self)
+        REGISTER._register_tox_env_types(self)  # noqa: SLF001
 
 
 def _load_inline(path: Path) -> ModuleType | None:  # used to be able to unregister plugin tests
